@@ -1,4 +1,4 @@
-/* $Id: svgalib.h,v 1.3 2001/06/24 16:45:12 skids Exp $
+/* $Id$
 ******************************************************************************
 
    LibGGI SVGAlib target
@@ -67,18 +67,19 @@ ggifunc_setreadframe	GGI_svga_setreadframe;
 ggifunc_setwriteframe	GGI_svga_setwriteframe;
 ggifunc_setdisplayframe	GGI_svga_setdisplayframe;
 
-ggifunc_setpalvec	GGI_svga_setpalvec;
-
+ggifunc_setPalette	GGI_svga_setPalette;
+size_t GGI_svga_getPrivSize(ggi_visual_t);
 
 /* We must use a wrapper around vga_setmode() because SVGAlib messes
    with terminal settings. */
 int _ggi_svgalib_setmode(int mode);
-
+void _GGI_svga_freedbs(ggi_visual *);
 
 typedef struct svga_priv {
+	PHYSZ_DATA
+
 	ggi_modelistmode *availmodes;
 	uint8	         *memorigin;
-	int		 *savepalette;
 	uint32	pixperframe;
 	int	islinear;
 	int	ismodex;
@@ -90,9 +91,7 @@ typedef struct svga_priv {
 	int	ismapped;
 	ggi_linvtsw_func *doswitch;
 	int	gfxmode;
-	int	physzflags;
 	int	frame_size;
-	ggi_coord	physz;
 } svga_priv;
 
 #define SVGA_PRIV(vis) ((svga_priv*)LIBGGI_PRIVATE(vis))
