@@ -1,4 +1,4 @@
-/* $Id: vcsa.h,v 1.2 2001/05/31 21:55:21 skids Exp $
+/* $Id: vcsa.h,v 1.4 2004/02/14 22:30:47 cegger Exp $
 ******************************************************************************
 
    Display-VCSA: definitions
@@ -34,15 +34,14 @@
 /* Visual-private data */
 
 typedef struct {	
+	PHYSZ_DATA
+
 	int width;
 	int height;
 
 	int inputs;
 	int flags;
 
-	int physzflags;
-	ggi_coord physz;
-
 } ggi_vcsa_priv;
 
 #define VCSA_PRIV(vis) ((ggi_vcsa_priv *) LIBGGI_PRIVATE(vis))
@@ -76,4 +75,7 @@ ggifunc_gethline	GGI_vcsa_gethline;
 ggifunc_mapcolor	GGI_vcsa_mapcolor;
 ggifunc_unmappixel	GGI_vcsa_unmappixel;
 
+extern int GGI_vcsa_resetmode(ggi_visual *vis);
+
+
 #endif /* _GGI_DISPLAY_VCSA_H */
