@@ -1,4 +1,4 @@
-/* $Id: ggi-unix.h,v 1.1.1.1 2001/05/12 23:03:18 cegger Exp $
+/* $Id: ggi-unix.h,v 1.2 2004/02/23 14:25:30 pekberg Exp $
 ******************************************************************************
 
    LibGGI UNIX-specific API header file
@@ -30,12 +30,13 @@
 
 #include <ggi/ggi.h>
 
+
 __BEGIN_DECLS
 
 /* Wait for filedescriptors and LibGGI events the the same time */
-int ggiEventSelect(ggi_visual_t vis, ggi_event_mask *mask, int n,
-		   fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
-		   struct timeval *timeout);
+GGIAPIFUNC int ggiEventSelect(ggi_visual_t vis, ggi_event_mask *mask, int n,
+			      fd_set *readfds, fd_set *writefds,
+			      fd_set *exceptfds, struct timeval *timeout);
 
 __END_DECLS
 
