@@ -1,4 +1,4 @@
-/* $Id: ggi_ext.h,v 1.1.1.1 2001/05/12 23:03:18 cegger Exp $
+/* $Id: ggi_ext.h,v 1.6 2004/02/23 14:25:30 pekberg Exp $
 ******************************************************************************
 
    Copyright (C) 1998      Andreas Beck		[becka@ggi-project.org]
@@ -41,14 +41,15 @@ typedef int ggi_extid;	/* Don't rely on that ! */
 
 __BEGIN_DECLS
 
-ggi_extid    ggiExtensionRegister(char *name, int size,
-			int (*paramchange)(ggi_visual_t,int whatchanged));
-int          ggiExtensionUnregister(ggi_extid id);
-int	     ggiExtensionAttach(ggi_visual_t vis,ggi_extid id);
-int	     ggiExtensionDetach(ggi_visual_t vis,ggi_extid id);
-ggi_lib_id   ggiExtensionLoadDL(ggi_visual_t vis, const char *filename,
-				const char *args, void *argptr,
-				const char *symprefix);
+GGIAPIFUNC ggi_extid    ggiExtensionRegister(char *name, size_t size,
+			  int (*paramchange)(ggi_visual_t,int whatchanged));
+GGIAPIFUNC int          ggiExtensionUnregister(ggi_extid id);
+GGIAPIFUNC int          ggiExtensionAttach(ggi_visual_t vis,ggi_extid id);
+GGIAPIFUNC int          ggiExtensionDetach(ggi_visual_t vis,ggi_extid id);
+GGIAPIFUNC ggi_lib_id   ggiExtensionLoadDL(ggi_visual_t vis,
+					   const char *filename,
+					   const char *args, void *argptr,
+					   const char *symprefix);
 
 __END_DECLS
 
