@@ -1,4 +1,4 @@
-/* $Id: types.h,v 1.4 2001/09/30 15:12:18 skids Exp $
+/* $Id: types.h,v 1.7.2.1 2004/11/04 12:45:06 cegger Exp $
 ******************************************************************************
 
    LibGGI general definitions, data structures, etc.
@@ -75,15 +75,16 @@ typedef uint32 ggi_graphtype;
 #define GT_SUBSCHEME_SHIFT	(16)
 #define GT_SCHEME_SHIFT		(24)
 
-#define GT_DEPTH_MASK		(0xff << GT_DEPTH_SHIFT)
-#define GT_SIZE_MASK		(0xff << GT_SIZE_SHIFT)
-#define GT_SUBSCHEME_MASK	(0xff << GT_SUBSCHEME_SHIFT)
-#define GT_SCHEME_MASK		(0xff << GT_SCHEME_SHIFT)
+#define GT_DEPTH_MASK		(0xffU << GT_DEPTH_SHIFT)
+#define GT_SIZE_MASK		(0xffU << GT_SIZE_SHIFT)
+#define GT_SUBSCHEME_MASK	(0xffU << GT_SUBSCHEME_SHIFT)
+#define GT_SCHEME_MASK		(0xffU << GT_SCHEME_SHIFT)
 
 /* Macros to extract info from a ggi_graphtype. */
 #define GT_DEPTH(x)		(((x) & GT_DEPTH_MASK) >> GT_DEPTH_SHIFT)
 #define GT_SIZE(x)		(((x) & GT_SIZE_MASK) >> GT_SIZE_SHIFT)
 #define GT_ByPP(x)		((GT_SIZE(x) + 7) / 8)
+#define GT_ByPPP(w,x)		(((w) * (GT_SIZE(x)) + 7) / 8)
 #define GT_SUBSCHEME(x)		((x) & GT_SUBSCHEME_MASK)
 #define GT_SCHEME(x)		((x) & GT_SCHEME_MASK)
 
@@ -206,7 +207,7 @@ typedef struct		/* requested by user and changed by driver    */
 #define GGI_PT_IS_COLOR4	0x00080000 /* A color channel (K)	     */
 #define GGI_PT_IS_ALPHA		0x00100000 /* A translucency  (A)	     */
 #define GGI_PT_IS_DEPTH		0x00200000 /* A depth	      (Z, Bump)	     */
-#define GGI_PT_IS_PAT		0x01000000 /* A pattern for tesslation fills */
+#define GGI_PT_IS_PAT		0x01000000 /* A pattern for tesselation fills*/
 #define GGI_PT_IS_CLIP		0x02000000 /* A clipping region		     */
 #define GGI_PT_IS_ERR		0x03000000 /* An error term		     */
 #define GGI_PT_IS_FGCOL		0x04000000 /* A foreground color	     */
